require 'fileutils'
require 'erb'

class RailsGae

  attr_reader :app_name, :rails_version

  alias_method :destination_folder, :app_name

  def initialize(app_name)
    rails_version = '2.3.11'
    @app_name = app_name
    @rails_version = rails_version
  end

  def run!
    create_rails_project
    copy_files
    generate_templates
  end

  def create_rails_project
    puts `rails _#{rails_version}_ #{app_name}`
  end

  def copy_files
    FileUtils.cp_r(File.join(files_dir, '.'), destination_folder)
  end

  def generate_templates
    FileUtils.cp_r(File.join(templates_dir, '.'), destination_folder)
    templates.each do |template|
      file = ERB.new(File.open(template).read)
      File.open(template, 'w+').write(file.result(binding))
    end
  end

  def files_dir
    File.join(File.dirname(__FILE__), 'generator', 'files')
  end

  def templates_dir
    File.join(File.dirname(__FILE__), 'generator', 'templates')
  end

  def templates
    templates = Dir.glob(File.join(templates_dir, '**', '*')).select{ |f| File.file?(f) }
    templates.map do |template_path|
      relative_path = template_path.sub(templates_dir, '')
      File.join(destination_folder, relative_path)
    end
  end
end
